from promptflow import tool
from typing import Dict, List


def generate_index_json(
    index_type: str = "",
    index: str = "",
    content_field: str = "",
    embedding_deployment=""
) -> str:
    """This is a dummy function to generate a index json from inputs.
    """

    import json
    inputs = {
        "index_type": index_type,
        "index": index,
        "content_field": content_field,
        "embedding_deployment": embedding_deployment,
    }

    result = json.dumps(inputs)
    return result


def reverse_generate_index_json(index_json: str) -> Dict:
    """This is a dummy function to generate origin inputs from index_json.
    """
    import json

    result = json.loads(index_json)
    return result


def list_indexes(index_type: str) -> List[str]:
    result = []
    if index_type == "Azure Cognitive Search":
        result = ["0", "1"]
    elif index_type == "MLIndex":
        result = ["2", "3"]
    return result


def list_content_fields(index_type: str) -> List[str]:
    result = []
    if index_type == "Azure Cognitive Search":
        result = ["a", "b"]
    elif index_type == "MLIndex":
        result = ["c", "d"]
    return result


def list_embedding_deployment(index_type: str) -> List[str]:
    result = []
    if index_type == "Azure Cognitive Search":
        result = ["u", "v"]
    elif index_type == "MLIndex":
        result = ["x", "y"]
    return result


@tool
def my_tool(
    index_json: str,
    index_type: str,
    index_assetId: str,
    content_fields: str,
    embedding_deployment: str
) -> str:
    return f"Hello {index_json}"



from promptflow import tool
from promptflow.connections import CustomStrongTypeConnection
from promptflow.contracts.types import Secret


class MyCustomConnection(CustomStrongTypeConnection):
    """My custom strong type connection.

    :param api_key: The api key get from "https://xxx.com".
    :type api_key: Secret
    :param api_base: The api base.
    :type api_base: String
    """
    api_key: Secret
    api_base: str = "This is a fake api base."


@tool
def my_tool(connection: MyCustomConnection, input_text: str) -> str:
    # Replace with your tool code.
    # Use custom strong type connection like: connection.api_key, connection.api_base
    return "Hello " + input_text



import json
import unittest

from my_tool_package.tools.tool_with_generated_by_input import (
    generate_index_json, list_content_fields,
    list_embedding_deployment,
    list_indexes,
    my_tool,
    reverse_generate_index_json,
)


def test_my_tool():
    index_type = "MLIndex"
    index = list_indexes(index_type)[0]
    content_field = list_content_fields(index_type)[0]
    embedding_deployment = list_embedding_deployment(index_type)[1]
    index_json = generate_index_json(
        index_type=index_type,
        index=index,
        content_field=content_field,
        embedding_deployment=embedding_deployment
    )

    result = my_tool(index_json, index_type, index, content_field, embedding_deployment)

    assert result == f'Hello {index_json}'


def test_generate_index_json():
    index_type = "MLIndex"
    index = list_indexes(index_type)[0]
    content_field = list_content_fields(index_type)[0]
    embedding_deployment = list_embedding_deployment(index_type)[1]

    index_json = generate_index_json(
        index_type=index_type,
        index=index,
        content_field=content_field,
        embedding_deployment=embedding_deployment
    )
    indexes = json.loads(index_json)

    assert indexes["index_type"] == index_type
    assert indexes["index"] == index
    assert indexes["content_field"] == content_field
    assert indexes["embedding_deployment"] == embedding_deployment


def test_list_indexes():
    index_type = "Azure Cognitive Search"
    result = list_indexes(index_type)
    assert len(result) == 2
    assert "1" in result


def test_list_content_fields():
    index_type = "MLIndex"
    result = list_content_fields(index_type)
    assert len(result) == 2
    assert "c" in result


def test_list_embedding_deployment():
    index_type = "MLIndex"
    result = list_embedding_deployment(index_type)
    assert len(result) == 2
    assert "x" in result


def test_reverse_generate_index_json():
    index_type = "MLIndex"
    index = list_indexes(index_type)[0]
    content_field = list_content_fields(index_type)[0]
    embedding_deployment = list_embedding_deployment(index_type)[1]
    indexes = {
        "index_type": index_type,
        "index": index,
        "content_field": content_field,
        "embedding_deployment": embedding_deployment,
    }
    input_json = json.dumps(indexes)

    result = reverse_generate_index_json(input_json)

    for k, v in indexes.items():
        assert result[k] == v


if __name__ == "__main__":
    unittest.main()



from my_tool_package.tools.tool_with_dynamic_list_input import my_tool, my_list_func


def test_my_tool():
    result = my_tool(input_text=["apple", "banana"], input_prefix="My")
    assert result == 'Hello My apple,banana'


def test_my_list_func():
    result = my_list_func(prefix="My")
    assert len(result) == 10
    assert "value" in result[0]



from promptflow import tool
from typing import List, Union, Dict


def my_list_func(prefix: str = "", size: int = 10, **kwargs) -> List[Dict[str, Union[str, int, float, list, Dict]]]:
    """This is a dummy function to generate a list of items.

    :param prefix: prefix to add to each item.
    :param size: number of items to generate.
    :param kwargs: other parameters.
    :return: a list of items. Each item is a dict with the following keys:
        - value: for backend use. Required.
        - display_value: for UI display. Optional.
        - hyperlink: external link. Optional.
        - description: information icon tip. Optional.
    """
    import random

    words = ["apple", "banana", "cherry", "date", "elderberry", "fig", "grape", "honeydew", "kiwi", "lemon"]
    result = []
    for i in range(size):
        random_word = f"{random.choice(words)}{i}"
        cur_item = {
            "value": random_word,
            "display_value": f"{prefix}_{random_word}",
            "hyperlink": f'https://www.bing.com/search?q={random_word}',
            "description": f"this is {i} item",
        }
        result.append(cur_item)

    return result


def list_endpoint_names(subscription_id, resource_group_name, workspace_name, prefix: str = "") -> List[Dict[str, str]]:
    """This is an example to show how to get Azure ML resource in tool input list function.

    :param subscription_id: Azure subscription id.
    :param resource_group_name: Azure resource group name.
    :param workspace_name: Azure ML workspace name.
    :param prefix: prefix to add to each item.
    """
    from azure.ai.ml import MLClient
    from azure.identity import DefaultAzureCredential

    credential = DefaultAzureCredential()
    credential.get_token("https://management.azure.com/.default")

    ml_client = MLClient(
        credential=credential,
        subscription_id=subscription_id,
        resource_group_name=resource_group_name,
        workspace_name=workspace_name)
    result = []
    for ep in ml_client.online_endpoints.list():
        hyperlink = (
            f"https://ml.azure.com/endpoints/realtime/{ep.name}/detail?wsid=/subscriptions/"
            f"{subscription_id}/resourceGroups/{resource_group_name}/providers/Microsoft."
            f"MachineLearningServices/workspaces/{workspace_name}"
        )
        cur_item = {
            "value": ep.name,
            "display_value": f"{prefix}_{ep.name}",
            # external link to jump to the endpoint page.
            "hyperlink": hyperlink,
            "description": f"this is endpoint: {ep.name}",
        }
        result.append(cur_item)
    return result


@tool
def my_tool(input_prefix: str, input_text: list, endpoint_name: str) -> str:
    return f"Hello {input_prefix} {','.join(input_text)} {endpoint_name}"



import pytest
import unittest

from promptflow.contracts.types import FilePath
from my_tool_package.tools.tool_with_file_path_input import my_tool


@pytest.fixture
def my_file_path_input() -> FilePath:
    my_file_path_input = FilePath("tests.test_utils.hello_method.py")
    return my_file_path_input


class TestToolWithFilePathInput:
    def test_tool_with_file_path_input(self, my_file_path_input):
        result = my_tool(my_file_path_input, input_text="Microsoft")
        assert result == "Hello Microsoft"


# Run the unit tests
if __name__ == "__main__":
    unittest.main()



from enum import Enum

from promptflow import tool


class UserType(str, Enum):
    STUDENT = "student"
    TEACHER = "teacher"


@tool
def my_tool(user_type: Enum, student_id: str = "", teacher_id: str = "") -> str:
    """This is a dummy function to support cascading inputs.

    :param user_type: user type, student or teacher.
    :param student_id: student id.
    :param teacher_id: teacher id.
    :return: id of the user.
    If user_type is student, return student_id.
    If user_type is teacher, return teacher_id.
    """
    if user_type == UserType.STUDENT:
        return student_id
    elif user_type == UserType.TEACHER:
        return teacher_id
    else:
        raise Exception("Invalid user.")



from setuptools import find_packages, setup

PACKAGE_NAME = "my-tools-package"

setup(
    name=PACKAGE_NAME,
    version="0.0.9",
    description="This is my tools package",
    packages=find_packages(),
    entry_points={
        "package_tools": ["my_tools = my_tool_package.tools.utils:list_package_tools"],
    },
    include_package_data=True,   # This line tells setuptools to include files from MANIFEST.in
    extras_require={
        "azure": [
            "azure-ai-ml>=1.11.0,<2.0.0"
        ]
    },
)
